@@ -1,8 +1,12 @@
 from django.db import models
 from django.db.models.fields import FieldDoesNotExist
 
+import django
+from distutils.version import StrictVersion
+
+from sampledata.exceptions import ParameterError
+
 from .helper import SampleDataHelper
-from .exceptions import ParameterError
 from .register import register
 
 # import the logging library
@@ -17,6 +21,12 @@ class ModelDataHelper(object):
         self.sd = SampleDataHelper(seed)
 
     def __get_instance_fields(self, instance):
+        django_version = django.get_version()
+        if StrictVersion(django_version) >= StrictVersion('1.8'):
+            return self.__get_instance_fields_django_18(instance)
+        return self.__get_instance_fields_django_other(instance)
+
+    def __get_instance_fields_django_other(self, instance):
         fields = []
         for field_name in instance._meta.get_all_field_names():
             try:
@@ -25,6 +35,15 @@ class ModelDataHelper(object):
                 pass
         return fields
 
+    def __get_instance_fields_django_18(self, instance):
+        fields = []
+        for field in instance._meta.get_fields():
+            try:
+                fields.append((field.name, field))
+            except FieldDoesNotExist:
+                pass
+        return fields
+
     def fill_model(self, model, number, *args, **kwargs):
         if number <= 0:
             raise ParameterError('number must be greater than 0')
